@@ -9,6 +9,7 @@
 
 #include <KParts/ReadOnlyPart>
 
+#include <QAction>
 #include <QUrl>
 
 class DolphinNewFileMenu;
@@ -20,7 +21,6 @@ class DolphinPartBrowserExtension;
 class DolphinRemoteEncoding;
 class KDirLister;
 class DolphinView;
-class KAboutData;
 class DolphinRemoveAction;
 
 class DolphinPart : public KParts::ReadOnlyPart
@@ -40,11 +40,10 @@ class DolphinPart : public KParts::ReadOnlyPart
     Q_PROPERTY( QList<QUrl> filesToSelect READ filesToSelect WRITE setFilesToSelect )
 
 public:
-    explicit DolphinPart(QWidget* parentWidget, QObject* parent, const QVariantList& args);
+    explicit DolphinPart(QWidget* parentWidget, QObject* parent,
+                         const KPluginMetaData& metaData, const QVariantList& args);
     ~DolphinPart() override;
 
-    static KAboutData* createAboutData();
-
     /**
      * Standard KParts::ReadOnlyPart openUrl method.
      * Called by Konqueror to view a directory in DolphinPart.
@@ -220,6 +219,8 @@ private:
 
     void openSelectionDialog(const QString& title, const QString& text,
                              bool selectItems);
+    QString urlToLocalFilePath(const QUrl &url);
+    QString localFilePathOrHome() const;
 
 private:
     DolphinView* m_view;
